capture log close
log using schiz, replace text
set more off
set scheme sj

use schiz, clear

* recode data
gen impso = imps
recode impso -9=. 1/2.4=1 2.5/4.4=2 4.5/5.4=3 5.5/7=4

* look at missingness patterns
xtdes, i(id) t(week)
table week treatment, contents(count impso) col

* produce graphs of proportions and estimated log odds
egen propg1 = mean(impso>1), by(week treatment)
egen propg2 = mean(impso>2), by(week treatment)
egen propg3 = mean(impso>3), by(week treatment)

egen nonrare = anymatch(week), values(0,1,3,6)

label def t 0 "Control" 1 "Treatment", modify
label values treatment t
sort treatment id week

twoway (line propg1 week, sort) ///
  (line propg2 week, sort clpatt(vshortdash))     ///
  (line propg3 week, sort clpatt(dash)) if nonrare==1, by(treatment) ///
  legend(order(1 "Prop(y>1)" 2 "Prop(y>2)" 3 "Prop(y>3)")) xtitle("Week")

gen logodds1 = ln(propg1/(1-propg1))
gen logodds2 = ln(propg2/(1-propg2))
gen logodds3 = ln(propg3/(1-propg3))

twoway (line logodds1 week, sort) ///
  (line logodds2 week, sort clpatt(vshortdash))     ///
  (line logodds3 week, sort clpatt(dash)) if nonrare==1, by(treatment) ///
  legend(order(1 "Log-Odds(y>1)" 2 "Log-Odds(y>2)" 3 "Log-Odds(y>3)")) xtitle("Week")

gen weeksqrt = sqrt(week)
twoway (line logodds1 weeksqrt, sort) ///
  (line logodds2 weeksqrt, sort clpatt(vshortdash))     ///
  (line logodds3 weeksqrt, sort clpatt(dash)) if nonrare==1, by(treatment) ///
  legend(order(1 "Log-Odds(y>1)" 2 "Log-Odds(y>2)" 3 "Log-Odds(y>3)")) xtitle("Square root of week")

* ordinary ordinal logit model
gen interact = weeksqrt*treatment
ologit impso weeksqrt treatment interact, or robust cluster(id)

lincom weeksqrt+interact, or

* plot of predicted probabilities and proportions
predict prob1-prob4, pr
gen probg3 = prob4
gen probg2 = prob3 + probg3
gen probg1 = prob2 + probg2

twoway (line propg1 week if nonrare==1, sort clpatt(solid)) ///
  (line propg2 week if nonrare==1, sort clpatt(vshortdash))     ///
  (line propg3 week if nonrare==1, sort clpatt(dash)) ///
  (line probg1 week, sort clpatt(solid)) ///
  (line probg2 week, sort clpatt(vshortdash))     ///
  (line probg3 week, sort clpatt(dash)) , by(treatment) ///
  legend(order(1 "Prob(y>1)" 2 "Prob(y>2)" 3 "Prob(y>3)")) xtitle("Week")

* random intercept model
gllamm impso weeksqrt treatment interact, i(id) link(ologit) adapt eform
estimates store model1

* random coefficient model
gen cons=1
eq inter: cons
eq slope: weeksqrt
matrix a=e(b)
matrix a=a,.1,0
gllamm impso weeksqrt treatment interact, i(id) nrf(2) eqs(inter slope) ///
   link(ologit) adapt from(a) copy
gllamm, eform
estimates store model2
lrtest model1 model2

* cumulative marginal probabilities
gllapred mprobg1, mu marg above(1)
gllapred mprobg2, mu marg above(2)
gllapred mprobg3, mu marg above(3)

twoway (line propg1 week if nonrare==1, sort clpatt(solid)) ///
  (line propg2 week if nonrare==1, sort clpatt(vshortdash))     ///
  (line propg3 week if nonrare==1, sort clpatt(dash)) ///
  (line mprobg1 week, sort clpatt(solid)) ///
  (line mprobg2 week, sort clpatt(vshortdash))     ///
  (line mprobg3 week, sort clpatt(dash)) , by(treatment) ///
  legend(order(1 "Prob(y>1)" 2 "Prob(y>2)" 3 "Prob(y>3)")) xtitle("Week")

* marginal probabilities of individual response categories
gen pr1 = 1-mprobg1
gen pr2 = mprobg1 - mprobg2
gen pr3 = mprobg2 - mprobg3
gen pr4 = mprobg3
twoway (line pr1 week, sort clpatt(solid))     ///
  (line pr2 week, sort clpatt(vshortdash))     ///
  (line pr3 week, sort clpatt(dash_dot))        ///
  (line pr4 week, sort clpatt(dash)), by(treatment) ///
  legend(order(1 "Prob(y=1)" 2 "Prob(y=2)" 3 ///
  "Prob(y=3)" 4 "Prob(y=4)")) xtitle("Week")

* patient-specific cumulative  probabilities
gllapred pprobg1, mu above(1)
gllapred pprobg2, mu above(2)
gllapred pprobg3, mu above(3)

gen week0 = week==0
sort treatment id week
by treatment: gen newid = sum(week0)

twoway (line pprobg1 week, sort clpatt(solid)) ///
  (line pprobg2 week, sort clpatt(vshortdash))     ///
  (line pprobg3 week, sort clpatt(dash)) if newid<13&treatment==0, by(newid) ///
  legend(order(1 "Prob(y>1)" 2 "Prob(y>2)" 3 "Prob(y>3)")) xtitle("Week")

twoway (line pprobg1 week, sort clpatt(solid)) ///
  (line pprobg2 week, sort clpatt(vshortdash))     ///
  (line pprobg3 week, sort clpatt(dash)) if newid<13&treatment==1, by(newid) ///
  legend(order(1 "Prob(y>1)" 2 "Prob(y>2)" 3 "Prob(y>3)")) xtitle("Week")

log close
exit
